@@ -949,7 +949,6 @@ class Compiler(object):
             module = ast.Module([])
             module.body += self.visit(node)
             ast.fix_missing_locations(module)
-            prelude = "__filename = %r\n__default = object()" % filename
             generator = TemplateCodeGenerator(module, source)
             tokens = [
                 Token(source[pos:pos + length], pos, source)
@@ -966,7 +965,7 @@ class Compiler(object):
                 self.lock.release()
 
         self.code = "\n".join((
-            prelude,
+            "__filename = %r\n" % filename,
             token_map_def,
             generator.code
         ))
@@ -1003,6 +1002,9 @@ class Compiler(object):
         body += template("from itertools import chain as __chain")
         if version < (3, 0, 0):
             body += template("from sys import exc_clear as __exc_clear")
+        else:
+            body += template("from sys import intern")
+        body += template("__default = intern('__default__')")
         body += template("__marker = object()")
         body += template(
             r"g_re_amp = re.compile(r'&(?!([A-Za-z]+|#[0-9]+);)')"
